@@ -14,7 +14,7 @@ use Fcntl qw(:flock);
 
 use Exporter qw(import);
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 our @EXPORT_OK = qw(start_server restart_server stop_server server_ports);
 
 my @signals_received;
@@ -223,6 +223,7 @@ sub start_server {
         die "fork failed:$!"
             unless defined $pid;
         if ($pid != 0) {
+            $path_remove_guard->dismiss;
             exit 0;
         }
         # in child process
@@ -231,6 +232,7 @@ sub start_server {
         die "fork failed:$!"
             unless defined $pid;
         if ($pid != 0) {
+            $path_remove_guard->dismiss;
             exit 0;
         }
         # do not close STDIN if `--port=n=0`.
@@ -271,7 +273,7 @@ sub start_server {
                 my @args = @{$opts->{exec}};
                 # child process
                 if (defined $opts->{dir}) {
-                    chdir $opts->{dir} or die "failed to chdir:$!";
+                    chdir $opts->{dir} or die "failed to chdir:$opts->{dir}:$!";
                 }
                 { exec { $args[0] } @args };
                 print STDERR "failed to exec $args[0]$!";
